@@ -37,8 +37,26 @@
 #include "trace-osm.h"
 #include "convert-osm-rcpp.h"
 
-//const std::string crs = "+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs +towgs84=0,0,0";
-const std::string p4s = "+proj=longlat +datum=WGS84 +no_defs";
+//const std::string crs = "EPSG:4326";
+const std::string wkt =
+"GEOGCRS[\"WGS 84\",\n\
+    DATUM[\"World Geodetic System 1984\",\n\
+        ELLIPSOID[\"WGS 84\",6378137,298.257223563,\n\
+            LENGTHUNIT[\"metre\",1]]],\n\
+    PRIMEM[\"Greenwich\",0,\n\
+        ANGLEUNIT[\"degree\",0.0174532925199433]],\n\
+    CS[ellipsoidal,2],\n\
+        AXIS[\"geodetic latitude (Lat)\",north,\n\
+            ORDER[1],\n\
+            ANGLEUNIT[\"degree\",0.0174532925199433]],\n\
+        AXIS[\"geodetic longitude (Lon)\",east,\n\
+            ORDER[2],\n\
+            ANGLEUNIT[\"degree\",0.0174532925199433]],\n\
+    USAGE[\n\
+        SCOPE[\"unknown\"],\n\
+        AREA[\"World\"],\n\
+        BBOX[-90,-180,90,180]],\n\
+    ID[\"EPSG\",4326]]";
 
 /************************************************************************
  ************************************************************************
